---
name: Bug report
about: Create a report to help us improve

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior.  This could be some simple steps in the provided samples, or a minimum, complete verifiable example of your own.  See https://stackoverflow.com/help/mcve for details.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots or cut and paste the erroneous text to help explain your problem.

**System details (please complete the following information):**
 - OS and version: [e.g. Windows 10
 - Asciimatics ersion [e.g. 1.9.0]

**Additional context**
Add any other context about the problem here.
